@@ -83,12 +83,16 @@ class SCTSolver:
                 list(atoAux.parseReactions(reaction)),
                 classification,
             )
+
+        # let's store each step separately for analysis downstream
+        self.database.scts = {}
+        self.database.scts["01_binding_sct"] = deepcopy(self.database.dependencyGraph)
+
         # lexical dependency graph contains lexically induced binding compositions. atomizer gives preference to binding obtained this way as opposed to stoichiometry
         # stronger bounds on stoichiometry based binding can be defined in
         # reactionDefinitions.json.
 
         for element in lexicalDependencyGraph:
-
             if (
                 element in self.database.dependencyGraph
                 and element not in self.database.userLabelDictionary
@@ -139,6 +143,11 @@ class SCTSolver:
                     # to indicate it is given less priority
                     self.database.dependencyGraph[molecule] = []
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["02_post_lexical_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         # user defined transformations
         for key in userEquivalenceTranslator:
             for namingEquivalence in userEquivalenceTranslator[key]:
@@ -150,6 +159,9 @@ class SCTSolver:
                     self.database.dependencyGraph, modElement, [baseElement]
                 )
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["03_post_user_sct"] = deepcopy(self.database.dependencyGraph)
+
         # self.database.eequivalence translator contains 1:1 equivalences
         # FIXME: do we need this update step or is it enough with the later one?
         # catalysis reactions
@@ -190,7 +202,6 @@ class SCTSolver:
                 len(self.database.userLabelDictionary[element][0]) == 0
                 or element == self.database.userLabelDictionary[element][0][0]
             ):
-
                 self.database.dependencyGraph[element] = []
             else:
                 self.database.dependencyGraph[element] = [
@@ -205,6 +216,11 @@ class SCTSolver:
                         self.database.userLabelDictionary[element][0][0]
                     ] = []
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["04_post_label_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         # add species elements defined by the user into the naming convention
         # definition
         molecules.extend(
@@ -231,7 +247,6 @@ class SCTSolver:
         # catalysis reactions
         for key in self.database.eequivalenceTranslator2:
             for namingEquivalence in self.database.eequivalenceTranslator2[key]:
-
                 baseElement = min(namingEquivalence, key=len)
                 modElement = max(namingEquivalence, key=len)
                 # dont overwrite user information
@@ -339,6 +354,11 @@ class SCTSolver:
                             ),
                         )
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["05_post_lex_catalysis_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         # non lexical-analysis catalysis reactions
         if self.database.forceModificationFlag:
             for reaction, classification in zip(rules, self.database.classifications):
@@ -358,7 +378,6 @@ class SCTSolver:
                         self.database.dependencyGraph[mod] == []
                         and mod not in self.database.userLabelDictionary
                     ):
-
                         if (
                             base in self.database.userLabelDictionary
                             and self.database.userLabelDictionary[base] == 0
@@ -441,6 +460,11 @@ class SCTSolver:
                                     continue
                         self.database.dependencyGraph[mod] = [[base]]
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["06_post_nonlex_catalysis_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         """
         #complex catalysis reactions
         for key in indirectEquivalenceTranslator:
@@ -511,6 +535,11 @@ class SCTSolver:
                     list(self.database.lexicalLabelDictionary[element][0])
                 ]
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["07_post_similarity_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         # Now let's go for annotation analysis and last resort stuff on the remaining orphaned molecules
         orphanedSpecies = [
             x
@@ -560,6 +589,11 @@ class SCTSolver:
                             self.database.dependencyGraph, element, []
                         )
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["08_post_annotation_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         # can we now add information to the non orphaned species? maybe annotation tells me stuff that contradicts the reaction-network
         nonOrphanedSpecies = [x for x in strippedMolecules if x not in orphanedSpecies]
 
@@ -619,6 +653,11 @@ class SCTSolver:
                             self.database.dependencyGraph, instance[0], []
                         )
 
+        # let's store each step separately for analysis downstream
+        self.database.scts["09_post_tiebreaker_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
         orphanedSpecies = [
             x
             for x in strippedMolecules
@@ -650,6 +689,15 @@ class SCTSolver:
                         reactant, greedyMatch
                     ),
                 )
+        # let's store each step separately for analysis downstream
+        self.database.scts["10_post_greedy_lex_sct"] = deepcopy(
+            self.database.dependencyGraph
+        )
+
+        # for key in self.database.scts:
+        #     print(key)
+        #     print(self.database.scts[key])
+
         if len(self.database.constructedSpecies) > 0:
             logMess(
                 "INFO:SCT031",
@@ -709,7 +757,6 @@ class SCTSolver:
                 combinationParticle[0] in annotationDict
                 and combinationParticle[1] in annotationDict
             ):
-
                 sortedPair = sorted(list(combinationParticle), key=len)
                 # get unary keys
                 unaryAnnotation1 = [
@@ -756,7 +803,6 @@ class SCTSolver:
                 ]
                 # unary keys match
                 if any([x in unaryAnnotation2 for x in unaryAnnotation1]):
-
                     exactMatches[sortedPair[1]].append([sortedPair[0]])
                 # one composes the other
                 elif any([x in compositionalAnnotation1 for x in unaryAnnotation2]):
@@ -787,7 +833,6 @@ class SCTSolver:
                 elif any(
                     [x in compositionalAnnotation2 for x in compositionalAnnotation1]
                 ):
-
                     intersectionMatches[sortedPair[1]].append([sortedPair[0]])
                     # intersectionMatches[combinationParticle[0]].append(combinationParticle[1])
         # create unary groups
@@ -915,7 +960,6 @@ class SCTSolver:
             equivalenceTranslator=equivalenceTranslator,
             equivalenceDictionary=equivalenceDictionary,
         ):
-
             tmpCandidates = []
             modifiedElementsPerCandidate = []
             unevenElements = []
@@ -928,7 +972,6 @@ class SCTSolver:
                         continue
                     modifiedElements = []
                     for chemical in individualAnswer:
-
                         # we cannot handle tuple naming conventions for now
                         if type(chemical) == tuple:
                             flag = False
@@ -1325,7 +1368,6 @@ class SCTSolver:
                                 # print self.database.userLabelDictionary
                                 return None, None, None
                         else:
-
                             if not self.database.softConstraints:
                                 if loginformation:
                                     modification = (
@@ -1518,7 +1560,6 @@ class SCTSolver:
                         namingtmpCandidates
                         and tmpCandidates[0] != namingtmpCandidates[0]
                     ):
-
                         if loginformation:
                             if (
                                 namingtmpCandidates[0][0]
