@@ -1,6 +1,4 @@
 import re, pyparsing, sympy, json
-from typing import Reversible
-from telnetlib import IP
 from bionetgen.atomizer.utils.util import logMess
 from bionetgen.atomizer.writer.bnglWriter import rindex
 
@@ -923,7 +921,6 @@ class Rule:
                 ):
                     txt += " 1*{}{}".format(self.rate_cts[0], conv)
                 else:
-
                     txt += " {}{}".format(self.rate_cts[0], conv)
 
         comment = ""
@@ -987,6 +984,7 @@ class bngModel:
         self.obs_map = {}
         self.molecule_mod_dict = {}
         self.parsed_func = {}
+        self.unitDefinitions = {}
         self.noCompartment = None
         self.useID = False
         self.replaceLocParams = False
@@ -1464,6 +1462,65 @@ class bngModel:
                     s.concCorrected = True
                     s.isConc = False
 
+    # def adjust_concentrations(self):
+    #     # some species are given as concentrations
+    #     # we need to convert them to amounts
+    #     if not self.noCompartment:
+    #         for spec in self.species:
+    #             s = self.species[spec]
+    #             if s.isConc:
+    #                 # pass
+    #                 # s.val = s.val * 1e-9
+    #                 # import IPython;IPython.embed()
+    #                 # conc = s.initConc * 6.022140857e23 * 1e-9
+    #                 conc = s.initConc
+    #                 if s.compartment in self.compartments:
+    #                     comp = self.compartments[s.compartment]
+    #                     # s.val = conc * comp.size
+    #                     s.val = conc
+    #                     s.concCorrected = True
+    #                     s.isConc = False
+    #                 else:
+    #                     s.val = conc
+    # we need to convert to amount
+    # if "substance" in unitDefinitions:
+    #     newParameterStr = self.convertToStandardUnitString(
+    #         rawSpecies["initialConcentration"],
+    #         unitDefinitions["substance"],
+    #     )
+    #     newParameter = self.convertToStandardUnits(
+    #         rawSpecies["initialConcentration"],
+    #         unitDefinitions["substance"],
+    #     )  # conversion to moles
+    # else:
+    #     newParameter = rawSpecies["initialConcentration"]
+    #     newParameterStr = str(rawSpecies["initialConcentration"])
+    # newParameter = (
+    #     newParameter * 6.022e23
+    # )  # convertion to molecule counts
+    # for factor in unitDefinition:
+    #     if factor["multiplier"] != 1:
+    #         parameterValue = "({0} * {1})".format(
+    #             parameterValue, factor["multiplier"]
+    #         )
+    #     if factor["exponent"] != 1:
+    #         parameterValue = "({0} ^ {1})".format(
+    #             parameterValue, factor["exponent"]
+    #         )
+    #     if factor["scale"] != 0:
+    #         parameterValue = "({0} * 1e{1})".format(parameterValue, factor["scale"])
+
+    # convert to molecule counts
+    #
+    # # get compartment size
+    # if self.noCompartment:
+    #     compartmentSize = 1.0
+    # else:
+    #     compartmentSize = self.model.getCompartment(
+    #         rawSpecies["compartment"]
+    #     ).getSize()
+    # newParameter = compartmentSize * newParameter
+
     def adjust_volume_corrections(self):
         if self.noCompartment:
             return
@@ -1503,6 +1560,7 @@ class bngModel:
             return
         if len(self.compartments) == 0:
             return
+        # import ipdb;ipdb.set_trace()
         for rule_name in self.rules:
             rule = self.rules[rule_name]
             # if rule.raw_splt:
@@ -1521,12 +1579,14 @@ class bngModel:
                             #     break
                             if spec_name in frate.definition:
                                 # means we got a volume to divide by
-                                # TODO: Wtf happens if this has multiple species?
+                                # TODO: Wtf happens if this has multiple species
                                 sp = self.species[spec_name]
                                 comp = self.compartments[sp.compartment]
                                 vol = comp.size
-                                frate.definition = frate.definition.replace(
-                                    spec_name, f"({spec_name}/{vol})"
+                                sub_from = r"(\W|^)({0})(\W|$)".format(spec_name)
+                                sub_to = r"\g<1>({0}/{1})\g<3>".format(spec_name, vol)
+                                frate.definition = re.sub(
+                                    sub_from, sub_to, frate.definition
                                 )
                                 # frate.volume_adjusted = True
                                 # break
