@@ -364,7 +364,6 @@ def getMoleculeByName(species, atom):
             stateVector = []
             for component in molecule.components:
                 if component.name == atom[1]:
-
                     # get whatever species this atom is bound to
                     if len(component.bonds) > 0:
                         comp = bondPartners(species, component.bonds[0])
@@ -554,7 +553,6 @@ def reorderFunctions(functions):
     functionNames = []
     tmp = []
     for function in functions:
-
         m = re.split("(?<=\()[\w)]", function)
         functionName = m[0]
         if "=" in functionName:
@@ -593,7 +591,7 @@ def postAnalysisHelper(outputFile, bngLocation, database):
     consoleCommands.bngl2xml(outputFile.split(os.sep)[-1])
     if outputDir != "":
         os.chdir(retval)
-    bngxmlFile = ".".join(outputFile.split(".")[:-1]) + ".xml"
+    bngxmlFile = ".".join(outputFile.split(".")[:-1]) + "_bngxml.xml"
     # print('Sending BNG-XML file to context analysis engine')
     contextAnalysis = postAnalysis.ModelLearning(bngxmlFile)
     # analysis of redundant bonds
@@ -619,7 +617,6 @@ def postAnalyzeFile(
     Performs a postcreation file analysis based on context information
     """
     # print('Transforming generated BNG file to BNG-XML representation for analysis')
-
     postAnalysisHelper(outputFile, bngLocation, database)
 
     # recreate file using information from the post analysis
@@ -639,7 +636,7 @@ def postAnalyzeFile(
         f.write(returnArray.finalString)
     # recompute bng-xml file
     consoleCommands.bngl2xml(outputFile)
-    bngxmlFile = ".".join(outputFile.split(".")[:-1]) + ".xml"
+    bngxmlFile = ".".join(outputFile.split(".")[:-1]) + "_bngxml.xml"
     # recompute context information
     contextAnalysis = postAnalysis.ModelLearning(bngxmlFile)
 
@@ -1131,7 +1128,6 @@ def analyzeHelper(
             initialConditions[flag] = "#" + initialConditions[flag]
 
     for flag in sorted(deleteMolecules, reverse=True):
-
         if deleteMoleculesFlag:
             logMess(
                 "WARNING:SIM101",
@@ -1419,6 +1415,10 @@ def analyzeHelper(
     for iobs, obs_str in enumerate(observables):
         oname = obs_str.split()[2]
         comp = None
+        # we can have multiple patterns and/or molecules, if so
+        # let's assume they are useful
+        if "." in oname:
+            continue
         if "@" in oname:
             if len(oname.split(":")) > 1:
                 # using @comp:spec
