@@ -323,7 +323,6 @@ def speciesAnnotationsToSBML(sbmlDocument, annotationDict, speciesNameDict):
         if len(annotationDict[transformedName]) == 0:
             continue
         for element in annotationDict[transformedName]:
-
             term = libsbml.CVTerm()
             if element.startswith("BQB"):
                 term.setQualifierType(libsbml.BIOLOGICAL_QUALIFIER)
@@ -443,13 +442,12 @@ def createDataStructures(bnglContent):
     retval = os.getcwd()
     os.chdir(tempfile.tempdir)
     consoleCommands.bngl2xml(pointer[1])
-    xmlfilename = ".".join(pointer[1].split(".")[0:-1]) + ".xml"
+    xmlfilename = ".".join(pointer[1].split(".")[0:-1]) + "_bngxml.xml"
     os.chdir(retval)
     return readBNGXML.parseXML(xmlfilename)
 
 
 def expandAnnotation(fileName, bnglFile):
-
     sct, database, sbmlDocument, _ = obtainSCT(
         fileName,
         "config/reactionDefinitions.json",
